@@ -8,16 +8,17 @@
 #
 package Dist::Zilla::Role::Git::Repo;
 # ABSTRACT: Provide repository information for Git plugins
-$Dist::Zilla::Role::Git::Repo::VERSION = '2.035';
+$Dist::Zilla::Role::Git::Repo::VERSION = '2.036';
 
 use Moose::Role;
+use MooseX::Types::Moose qw(Str Maybe);
 
-has 'repo_root'   => ( is => 'ro', isa => 'Str', default => '.' );
+has 'repo_root'   => ( is => 'ro', isa => Str, default => '.' );
 
 
 has current_git_branch => (
     is => 'ro',
-    isa => 'Maybe[Str]',
+    isa => Maybe[Str],
     lazy => 1,
     builder => '_build_current_git_branch',
     init_arg => undef,          # Not configurable
@@ -76,7 +77,7 @@ Dist::Zilla::Role::Git::Repo - Provide repository information for Git plugins
 
 =head1 VERSION
 
-version 2.035
+version 2.036
 
 =head1 DESCRIPTION
 
